/*
Copyright 2021 Plume Qi <plumeqi@gmail.com>

Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:
  
The above copyright notice and this permission notice shall be included
in all copies or substantial portions of the Software.
	
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/
#ifndef __SPLASHER_H__
#define __SPLASHER_H__

#include <Windows.h>
#include <tchar.h>

#ifdef __cplusplus
extern "C" {
#endif

/*The flags passed to SetLayeredWindowAttributes*/
#define FLAG_LWA_COLORKEY    0x00000001
#define	FLAG_LWA_ALPHA       0x00000002
/*Should the window have a drop shadow effect*/
#define FLAG_DROPSHADOW      0x00000004
#define FLAG_DRAGGABLE       0x00000008

#define ARGB(a, r, g, b) ((DWORD)(((BYTE)(r)|((WORD)((BYTE)(g))<<8))|(((DWORD)(BYTE)(b))<<16)|(((DWORD)(BYTE)(a))<<24)))


/*
hInstance: Instance handle
lpszName   : If bRes is TRUE, lpszName is resource name of splash bitmap, you can convert resource id to resource name via 
           MAKEINTRESOURCE; If bRes is FALSE, lpszName is file name of splash bitmap.
bRes       : Specify to use resource or file, TRUE for resource, FALSE for file.
dwFlag     : Specify splash window styles. If FLAG_LWA_COLORKEY and/or FLAG_LWA_ALPHA is specified, you need pass a ARGB color
             to dwARGB. FLAG_DROPSHADOW, splash window has dropshadow style; FLAG_DRAGGABLE, splash window can be draggable via 
		     hold and move mouse left button.
dwFlag     : All pixels painted by splash window in RGB color of ARGB will be transparent. Alpha value (A of ARGB) used to 
             describe the opacity of splash window, 0, splash window is completely transparent; 255, splash window is opaque.
lpszSound  : Splash sound file or resource
bReSound   : TRUE, splash sound is from resource; FALSE, sound is from file
dwShowTime : If loading process is short, the splash will be flashed and gone. Specify the param with milliseconds, the splash 
             will be destryed when dwShowTime expired. If loading time is greater than dwShowTime, the splash will be destroyed
			 until loading process is finished.
*/
BOOL Splash_Create(HINSTANCE hInstance, LPCTSTR lpszName, BOOL bRes, DWORD dwFlag, DWORD dwARGB,LPCTSTR lpszSound,BOOL bResSound,DWORD dwShowTime);
void Splash_ShowText(LPCTSTR lpszText,COLORREF clrTextColor);
/*hWndActive windows will be activated after splash showing*/
BOOL Splash_Close(HWND hWndActive);

#ifdef __cplusplus
}
#endif

#endif
